# Taoshi Trading System Package Reservation

This is not a usable Python package, but the name is reserved by Taoshi Inc.

See [taoshi.io](https://taoshi.io/) for details on Taoshi Inc's Python libraries and trademarks.
